@@ -1,5 +1,5 @@
 #!/bin/sh
-V="5.3"
+V="5.5.1"
 prefix=/usr
 infodir=${prefix}/share/info
 docdir=${prefix}/share/doc
